/*=========================================================================

  Program:   Visualization Toolkit
  Module:    vtkInformationRequestKey.h

  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
  All rights reserved.
  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.

     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
// .NAME vtkInformationRequestKey - Key for pointer to pointer.
// .SECTION Description
// vtkInformationRequestKey is used to represent keys for pointer
// to pointer values in vtkInformation.h

#ifndef __vtkInformationRequestKey_h
#define __vtkInformationRequestKey_h

#include "vtkInformationKey.h"

#include "vtkCommonInformationKeyManager.h" // Manage instances of this type.

class VTK_COMMON_EXPORT vtkInformationRequestKey : public vtkInformationKey
{
public:
  vtkTypeMacro(vtkInformationRequestKey,vtkInformationKey);
  void PrintSelf(ostream& os, vtkIndent indent);

  vtkInformationRequestKey(const char* name, const char* location);
  ~vtkInformationRequestKey();

  // Description:
  // Get/Set the value associated with this key in the given
  // information object.
  void Set(vtkInformation* info);
  void Remove(vtkInformation* info);
  int Has(vtkInformation* info);

  // Description:
  // Copy the entry associated with this key from one information
  // object to another.  If there is no entry in the first information
  // object for this key, the value is removed from the second.
  virtual void ShallowCopy(vtkInformation* from, vtkInformation* to);

  // Description:
  // Print the key's value in an information object to a stream.
  virtual void Print(ostream& os, vtkInformation* info);

private:
  vtkInformationRequestKey(const vtkInformationRequestKey&);  // Not implemented.
  void operator=(const vtkInformationRequestKey&);  // Not implemented.
};

#endif
